"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _authenticate_wrapper = _interopRequireDefault(require("./authenticate_wrapper"));

var _create_response = _interopRequireDefault(require("./create_response"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const authStrategies = new Map();

const callbackInvoker = async function (...args) {
  const strategyArgs = args.slice(0, args.length - 1);
  const done = args[args.length - 1];

  try {
    done(null, await this.apiCallback(this.currentReq, ...strategyArgs));
  } catch (error) {
    done(error);
  }
};

const getBaseStrategyAndOptions = (strategyHash, createStrategy, options) => {
  if (!authStrategies.has(strategyHash)) {
    const strategyDescriptor = createStrategy(options);
    const originalOptions = strategyDescriptor.options;
    const StrategyFactory = strategyDescriptor.factory;
    const strategyBase = new StrategyFactory(originalOptions, callbackInvoker);
    authStrategies.set(strategyHash, {
      strategyBase,
      originalOptions
    });
  }

  return authStrategies.get(strategyHash);
};

const TIMEOUT = 30000;

const executeStrategy = async (authRequest, createStrategy, options, strategyHash, callback) => {
  const {
    jwtCookie,
    rootPath
  } = authRequest.resolve;
  const {
    strategyBase,
    originalOptions
  } = getBaseStrategyAndOptions(strategyHash, createStrategy, options);
  const internalRes = (0, _create_response.default)();
  const strategy = Object.create(strategyBase);
  Object.assign(strategy, { ..._authenticate_wrapper.default,
    _verify: callbackInvoker,
    apiCallback: callback,
    currentReq: authRequest,
    originalOptions,
    internalRes,
    jwtCookie,
    rootPath
  });
  strategy.authDonePromise = new Promise((resolve, reject) => {
    strategy.resolveAuth = resolve;
    strategy.rejectAuth = reject;
  });
  strategy.authenticate(authRequest, {
    response: internalRes
  });
  setTimeout(strategy.rejectAuth, TIMEOUT);
  await strategy.authDonePromise;
  return internalRes;
};

var _default = executeStrategy;
exports.default = _default;
//# sourceMappingURL=execute_strategy.js.map