"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _uuid = require("uuid");

const createUserModule = strategies => {
  if (!Array.isArray(strategies)) {
    throw new Error(`Module Auth accepts strategies argument only as array`);
  }

  const apiHandlers = [];

  for (const strategyDescriptor of strategies) {
    const {
      createStrategy,
      options,
      routes,
      logoutRoute
    } = strategyDescriptor;
    const strategyHash = (0, _uuid.v4)();

    if (options != null && options.constructor !== Object) {
      throw new Error(`Vary options should be object if present`);
    }

    for (const {
      method,
      path: routePath,
      callback
    } of routes) {
      apiHandlers.push({
        method,
        path: `/api/${routePath}`,
        handler: {
          module: '@resolve-js/module-auth/lib/api_handler_constructor',
          options: {
            strategyHash,
            options
          },
          imports: {
            createStrategy,
            callback
          }
        }
      });
    }

    if (logoutRoute) {
      apiHandlers.push({
        method: logoutRoute.method,
        path: `/api/${logoutRoute.path}`,
        handler: '@resolve-js/module-auth/lib/logout_api_handler'
      });
    }
  }

  return {
    apiHandlers
  };
};

var _default = createUserModule;
exports.default = _default;
//# sourceMappingURL=index.js.map